..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Gradient Push Button Example
===============================================================================

An example of using style sheets to create a gradient PushButton.

.. TIP:: To see this example in action, download it from
 :download:`gradient_push_button <../../../examples/styling/gradient_push_button.enaml>`
 and run::

   $ enaml-run gradient_push_button.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_gradient_push_button.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/styling/gradient_push_button.enaml
    :language: enaml
